Package: miaDash
Version: 1.2.0
Authors@R: 
    c(person(given = "Giulio", family = "Benedetti", role = c("aut", "cre"),
           email = "giulio.benedetti@utu.fi",
           comment = c(ORCID = "0000-0002-8732-7692")),
    person(given = "Akewak", family = "Jeba", role = c("ctb"),
             email = "akewak.k.jeba@utu.fi",
             comment = c(ORCID = "0009-0007-1347-7552")),
    person(given = "Leo", family = "Lahti", role = c("aut"),
             email = "leo.lahti@iki.fi",
             comment = c(ORCID = "0000-0001-5537-637X")))
Title: Dashboard for the interactive analysis and exploration of
        microbiome data
Description: 
    miaDash provides a Graphical User Interface for the exploration of
    microbiome data. This way, no knowledge of programming is required to
    perform analyses. Datasets can be imported, manipulated, analysed and
    visualised with a user-friendly interface.
biocViews: Microbiome, Software, Visualization, GUI, ShinyApps,
        DataImport
License: Artistic-2.0
Encoding: UTF-8
Depends: R (>= 4.4.0), iSEE (>= 2.19.4), shiny
Imports: ape, bluster, htmltools, iSEEtree (>= 1.1.4), mia, rintrojs,
        scater, scuttle, shinydashboard, shinyjs, shinyWidgets,
        S4Vectors, SingleCellExperiment, SummarizedExperiment,
        TreeSummarizedExperiment, utils, vegan
Suggests: BiocStyle, knitr, philr, remotes, rmarkdown, testthat (>=
        3.0.0)
URL: https://github.com/microbiome/miaDash
BugReports: https://github.com/microbiome/miaDash/issues
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.3
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/miaDash
git_branch: RELEASE_3_22
git_last_commit: b230dcf
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 05:04:09 UTC; biocbuild
Author: Giulio Benedetti [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8732-7692>),
  Akewak Jeba [ctb] (ORCID: <https://orcid.org/0009-0007-1347-7552>),
  Leo Lahti [aut] (ORCID: <https://orcid.org/0000-0001-5537-637X>)
Maintainer: Giulio Benedetti <giulio.benedetti@utu.fi>
