# Generated by roxygen2: do not edit by hand

export(miaDash)
importFrom(S4Vectors,DataFrame)
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,assayNames)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(TreeSummarizedExperiment,TreeSummarizedExperiment)
importFrom(TreeSummarizedExperiment,rowTree)
importFrom(ape,read.tree)
importFrom(bluster,DmmParam)
importFrom(bluster,HclustParam)
importFrom(bluster,KmeansParam)
importFrom(bluster,NNGraphParam)
importFrom(htmltools,HTML)
importFrom(htmltools,br)
importFrom(htmltools,div)
importFrom(htmltools,tagList)
importFrom(htmltools,tags)
importFrom(iSEE,iSEE)
importFrom(iSEEtree,.check_all_panels)
importFrom(iSEEtree,AbundanceDensityPlot)
importFrom(iSEEtree,AbundancePlot)
importFrom(iSEEtree,ColumnGraphPlot)
importFrom(iSEEtree,ColumnTreePlot)
importFrom(iSEEtree,LoadingPlot)
importFrom(iSEEtree,PrevalencePlot)
importFrom(iSEEtree,RDAPlot)
importFrom(iSEEtree,RowGraphPlot)
importFrom(iSEEtree,RowTreePlot)
importFrom(iSEEtree,ScreePlot)
importFrom(mia,addAlpha)
importFrom(mia,addCluster)
importFrom(mia,addHierarchyTree)
importFrom(mia,addPrevalence)
importFrom(mia,addPrevalentAbundance)
importFrom(mia,agglomerateByRank)
importFrom(mia,getDissimilarity)
importFrom(mia,getTaxonomyLabels)
importFrom(mia,importBIOM)
importFrom(mia,importHUMAnN)
importFrom(mia,importMetaPhlAn)
importFrom(mia,importMothur)
importFrom(mia,importQIIME2)
importFrom(mia,runNMDS)
importFrom(mia,runRDA)
importFrom(mia,subsetByPrevalent)
importFrom(mia,subsetByRare)
importFrom(mia,taxonomyRanks)
importFrom(mia,transformAssay)
importFrom(rintrojs,introjs)
importFrom(scater,runMDS)
importFrom(scater,runPCA)
importFrom(scuttle,addPerCellQC)
importFrom(shinyWidgets,addSpinner)
importFrom(shinydashboard,box)
importFrom(shinydashboard,dashboardBody)
importFrom(shinydashboard,dashboardHeader)
importFrom(shinydashboard,dashboardPage)
importFrom(shinydashboard,dashboardSidebar)
importFrom(shinyjs,disable)
importFrom(shinyjs,enable)
importFrom(stats,as.formula)
importFrom(utils,data)
importFrom(utils,packageVersion)
importFrom(utils,read.table)
importFrom(vegan,vegdist)
