% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/observers.R
\name{create_observers}
\alias{create_observers}
\alias{.create_import_observers}
\alias{.create_manipulate_observers}
\alias{.create_estimate_observers}
\alias{.update_observers}
\alias{.create_launch_observers}
\title{Observers}
\usage{
.create_import_observers(input, rObjects)

.create_manipulate_observers(input, rObjects)

.create_estimate_observers(input, rObjects)

.update_observers(input, session, rObjects)

.create_launch_observers(FUN, input, session, rObjects)
}
\arguments{
\item{input}{The Shiny input object from the server function.}

\item{rObjects}{A reactive list of values generated in the landing page.}
}
\value{
Observers are created in the server function in which this is called.
A \code{NULL} value is invisibly returned.
}
\description{
\code{.create_observers} and \code{.create_launch_observers} define the
server to import and build TreeSE objects and track the state of the Build
and Launch buttons.
}
\keyword{internal}
