% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/constants.R
\docType{data}
\name{constants}
\alias{constants}
\alias{.miaDashDefaultPanels}
\alias{.miaDashOtherPanels}
\alias{.transformMethods}
\alias{.qualityMetrics}
\alias{.alphaMetrics}
\alias{.betaMetrics}
\alias{.betaMethods}
\alias{.clustMethods}
\alias{.DmmCriteria}
\title{Constants}
\format{
An object of class \code{character} of length 7.

An object of class \code{character} of length 9.

An object of class \code{character} of length 19.

An object of class \code{list} of length 4.

An object of class \code{character} of length 23.

An object of class \code{character} of length 4.

An object of class \code{character} of length 4.

An object of class \code{character} of length 4.

An object of class \code{character} of length 3.
}
\usage{
.miaDashDefaultPanels

.miaDashOtherPanels

.transformMethods

.qualityMetrics

.alphaMetrics

.betaMetrics

.betaMethods

.clustMethods

.DmmCriteria
}
\description{
Constant values used throughout the miaDash app.
}
\section{Panel layout}{

\describe{
\item{\code{.miaDashDefaultPanels}}{List of panel names in the default layout of miaDash.}
\item{\code{.miaDashOtherPanels}}{List of panel names not in the default layout of miaDash.}
\item{\code{.transformMethods}}{List of transformations applicable to assays.}
\item{\code{.alphaMetrics}}{List of alpha diversity metrics.}
\item{\code{.betaMetrics}}{List of beta diversity metrics.}
\item{\code{.betaMethods}}{List of beta diversity methods.}
\item{\code{.qualityMetrics}}{List of metrics for quality control.}
}
}

\author{
Giulio Benedetti
}
\keyword{datasets}
\keyword{internal}
