% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/outputs.R
\name{render_output}
\alias{render_output}
\alias{.render_overview}
\alias{.render_download}
\title{Outputs}
\usage{
.render_overview(output, rObjects)

.render_download(output, rObjects)
}
\arguments{
\item{output}{The Shiny output object from the server function.}
}
\value{
Adds a rendered item to \code{output}.
A \code{NULL} value is invisibly returned.
}
\description{
\code{.render_overview} and \code{.render_download} create the output of the
UI, which consists of the overview of the TreeSE object and the download
object, respectively.
}
\keyword{internal}
