% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/landing_page.R
\name{landing_page}
\alias{landing_page}
\alias{.landing_page}
\title{Landing page}
\usage{
.landing_page(FUN, input, output, session)
}
\value{
The UI is defined by the function. A \code{NULL} value is invisibly
returned.
}
\description{
\code{.landing_page} creates the landing page of miaDash, where TreeSE objects
can be built and iSEE can be launched.
}
\keyword{internal}
